==> fixthis-0.1.3.tar.gz: fixthis-0.1.3/src/fixthis_internal/interpreter.py <==
globals()["fixed"] = True
import sys
from ast import *
import inspect
import unicodedata as ucd
from fixthis_internal.number_converter import parse_english_number

pypy = False  # No pypy support for now


class FixVisitor(NodeTransformer):
    def visit_Name(self, node):
        if not isinstance(node.ctx, Load):
            return node
        return Call(
            func=Name(id="___fixthis_internal_name___", ctx=Load()),
            args=[
                Constant(value=node.id),
                Call(func=Name(id="locals", ctx=Load()), keywords=[], args=[]),
                Call(func=Name(id="globals", ctx=Load()), keywords=[], args=[]),
                (
                    Attribute(
                        value=Name(id="__builtins__", ctx=Load()),
                        attr="__dict__",
                        ctx=Load(),
                    )
                    if pypy
                    else (Name(id="__builtins__", ctx=Load()))
                ),
            ],
            keywords=[],
        )

    #    def visit_Raise(self, node): ...


_args = sys.argv
if len(_args) > 1:
    source_file = _args[1]
else:
    source_file = _args[0]

with open(source_file, "r") as f:
    source = f.read()

source_tree = FixVisitor().visit(parse(source, filename=source_file))
source_tree = fix_missing_locations(source_tree)


# helper to resolve names at runtime
def ___fixthis_internal_name___(varname, *scopes):
    for scope in scopes:
        if varname in scope:
            return scope[varname]

    if len(varname) > 0 and varname[0] == "_":
        try:
            return ucd.lookup(varname[1:].replace("_", " ").upper())
        except:
            ...
    try:
        return parse_english_number(varname)
    except:
        return varname


compiled = compile(source_tree, source_file, mode="exec")

# execution environment including helper function
env = {
    "__name__": "__main__",
    "__doc__": None,
    "__package__": None,
    "__loader__": None,
    "__spec__": ("python-fixthis", 0, 0, 1),
    "__annotations__": {},
    "__file__": source_file,
    "__cached__": None,
    "fixed": True,
    "___fixthis_internal_name___": ___fixthis_internal_name___,
}
exec(compiled, env)

==> fixthis-0.1.4.tar.gz: fixthis-0.1.4/src/fixthis_internal/interpreter.py <==
globals()["fixed"] = True
import sys
from ast import *
import inspect
import unicodedata as ucd
from fixthis_internal.number_converter import parse_english_number

pypy = False  # No pypy support for now


class FixVisitor(NodeTransformer):
    def visit_Name(self, node):
        if not isinstance(node.ctx, Load):
            return node
        return Call(
            func=Name(id="___fixthis_internal_name___", ctx=Load()),
            args=[
                Constant(value=node.id),
                Call(func=Name(id="locals", ctx=Load()), keywords=[], args=[]),
                Call(func=Name(id="globals", ctx=Load()), keywords=[], args=[]),
                (
                    Attribute(
                        value=Name(id="__builtins__", ctx=Load()),
                        attr="__dict__",
                        ctx=Load(),
                    )
                    if pypy
                    else (Name(id="__builtins__", ctx=Load()))
                ),
            ],
            keywords=[],
        )

    #    def visit_Raise(self, node): ...


_args = sys.argv
if len(_args) > 1:
    source_file = _args[1]
else:
    source_file = _args[0]

with open(source_file, "r", encoding="utf8") as f:
    source = f.read()

source_tree = FixVisitor().visit(parse(source, filename=source_file))
source_tree = fix_missing_locations(source_tree)


# helper to resolve names at runtime
def ___fixthis_internal_name___(varname, *scopes):
    for scope in scopes:
        if varname in scope:
            return scope[varname]

    if len(varname) > 0 and varname[0] == "_":
        try:
            return ucd.lookup(varname[1:].replace("_", " ").upper())
        except:
            ...
    try:
        return parse_english_number(varname)
    except:
        return varname


compiled = compile(source_tree, source_file, mode="exec")

# execution environment including helper function
env = {
    "__name__": "__main__",
    "__doc__": None,
    "__package__": None,
    "__loader__": None,
    "__spec__": ("python-fixthis", 0, 0, 1),
    "__annotations__": {},
    "__file__": source_file,
    "__cached__": None,
    "fixed": True,
    "___fixthis_internal_name___": ___fixthis_internal_name___,
}
exec(compiled, env)
